<a href="https://github.com/KennethEnevoldsen/scandinavian-embedding-benchmark"><img src="https://github.com/KennethEnevoldsen/scandinavian-embedding-benchmark/blob/main/docs/_static/logo.png?raw=true" width="120" align="right"/></a>

# Scandinavian Embedding Benchmark

[![PyPI](https://img.shields.io/pypi/v/seb.svg)][pypi status]
[![Python Version](https://img.shields.io/pypi/pyversions/seb)][pypi status]
[![documentation](https://github.com/KennethEnevoldsen/scandinavian-embedding-benchmark/actions/workflows/documentation.yml/badge.svg)][documentation]
[![Tests](https://github.com/KennethEnevoldsen/scandinavian-embedding-benchmark/actions/workflows/tests.yml/badge.svg)][tests]
[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)]([ruff])
[![DOI](https://zenodo.org/badge/671737258.svg)](https://zenodo.org/doi/10.5281/zenodo.10078411)

[pypi status]: https://pypi.org/project/seb/
[documentation]: https://KennethEnevoldsen.github.io/scandinavian-embedding-benchmark/
[tests]: https://github.com/KennethEnevoldsen/scandinavian-embedding-benchmark/actions?workflow=Tests
[ruff]: https://github.com/astral-sh/ruff


<!-- start short-description -->

A benchmark for evaluating sentence/document embeddings of Scandinavian language models.

<!-- end short-description -->

## Installation

You can install the Scandinavian Embedding Benchmark (`seb`) via [pip] from [PyPI]:

```bash
pip install seb
```

[pip]: https://pip.pypa.io/en/stable/installing/
[PyPI]: https://pypi.org/project/seb/


To see more examples, see the [documentation].

# 📖 Documentation

| Documentation         |                                                          |
| --------------------- | -------------------------------------------------------- |
| 🔧 **[Installation]**  | Installation instructions on how to install this package |
| 👩‍💻 **[Usage]**         | Introduction on how to use the package                   |
| 📖 **[Documentation]** | A minimal and developing documentation                   |


# 💬 Where to ask questions

| Type                           |                        |
| ------------------------------ | ---------------------- |
| 🚨 **Bug Reports**              | [GitHub Issue Tracker] |
| 🎁 **Feature Requests & Ideas** | [GitHub Issue Tracker] |
| 👩‍💻 **Usage Questions**          | [GitHub Discussions]   |
| 🗯 **General Discussion**       | [GitHub Discussions]   |

[Usage]: https://kennethenevoldsen.github.io/scandinavian-embedding-benchmark/getting_started/
[Documentation]: https://KennethEnevoldsen.github.io/scandinavian-embedding-benchmark/index.html
[Installation]: https://KennethEnevoldsen.github.io/scandinavian-embedding-benchmark/installation.html
[github issue tracker]: https://github.com/KennethEnevoldsen/scandinavian-embedding-benchmark/issues
[github discussions]: https://github.com/KennethEnevoldsen/scandinavian-embedding-benchmark/discussions


